import { stringifyEntityRef } from '@backstage/catalog-model';

class BatchLoader {
  constructor(options) {
    this.logger = options.logger;
    this.manager = options.databaseManager;
  }
  async getClient() {
    if (!this.client) {
      this.client = await this.manager.forPlugin("catalog").getClient();
    }
    return this.client;
  }
  async getEntitiesByRefs(refs) {
    this.logger.info(`Loading entities for refs: ${refs}`);
    const client = await this.getClient();
    const stringifiedRefs = refs.map((ref) => typeof ref === "string" ? ref : stringifyEntityRef(ref));
    const rows = await client("final_entities").select("final_entity as entity", "refresh_state.entity_ref as ref").join("refresh_state", "final_entities.entity_id", "refresh_state.entity_id").whereIn("refresh_state.entity_ref", stringifiedRefs);
    const unsortedEntities = new Map(rows.map((row) => [row.ref, JSON.parse(row.entity)]));
    const entities = stringifiedRefs.map((ref) => unsortedEntities.get(ref));
    this.logger.info(`Loaded ${entities.length} entities`);
    return entities;
  }
}

export { BatchLoader };
//# sourceMappingURL=index.esm.js.map
